@@ -11,8 +11,8 @@ class ImageMetrics():
 		left_img, right_img = self.split_stereo_into_l_r(img)
 		self.left_grids, self.right_grids = self.create_image_grids(left_img, 
 		                                                            right_img,
-																	m=m,
-																	n=n)
+																	m_dim=m,
+																	n_dim=n)
 		unequal_grids_msg = "left and right grid sizes do not match!"
 		assert len(self.left_grids) == len(self.right_grids), unequal_grids_msg
 	
@@ -46,15 +46,15 @@ class ImageMetrics():
 
 		return left_img, right_img
 
-	def create_image_grids(self, img, m=2, n=2):
+	def create_image_grids(self, img, m_dim=2, n_dim=2):
 		# section the numpy array of the image into m x n 
 		tiles = []
 
-		m_width = img.shape[0]//m
-		n_height = img.shape[1]//n
+		m_width = img.shape[0]//m_dim
+		n_height = img.shape[1]//n_dim
 
-		for i in range(0, m):
-			for j in range(0, n):
+		for i in range(0, m_dim):
+			for j in range(0, n_dim):
 				tile = img[i*m_width:(i+1)*m_width,j*n_height:(j+1)*n_height,:]
 				tiles.append(tile)
 		return tiles
